@@ -9,14 +9,14 @@ from gwproto import Message
 from gwproto import MQTTCodec
 from gwproto import create_message_payload_discriminator
 from gwproto.gs import GsPwr_Maker
-from gwproto.gt.gt_sh_status import GtShStatus_Maker
-from gwproto.gt.snapshot_spaceheat import SnapshotSpaceheat_Maker
 from gwproto.messages import Problems
+from gwproto.types import GtShStatus_Maker
+from gwproto.types import PowerWatts_Maker
+from gwproto.types import SnapshotSpaceheat_Maker
 from result import Err
 from result import Ok
 from result import Result
 
-from gwdcli.events.models import AnyEvent
 from gwdcli.events.models import GWDEvent
 from gwdcli.events.models import MQTTException
 from gwdcli.events.models import MQTTFullySubscribedEvent
@@ -95,6 +95,7 @@ class GwdMQTTCodec(MQTTCodec):
                 [
                     GtShStatus_Maker,
                     SnapshotSpaceheat_Maker,
+                    PowerWatts_Maker,
                 ],
                 message_payload_discriminator=GWDMessageDecoder,
             ).add_decoder(
@@ -119,42 +120,17 @@ class GwdMQTTCodec(MQTTCodec):
 def handle_message(
     message: aiomqtt.Message, queue: asyncio.Queue, decoder: GwdMQTTCodec
 ) -> None:
-    logger.debug("++mqtt message")
-    path_dbg = 0
     try:
-        pass_on_message = None
-        pass_on_error_event = None
-        message_str = message.payload.decode("utf-8")
-        result = AnyEvent.from_str(message_str)
-        if result.is_ok():
-            path_dbg |= 0x00000001
-            if result.value is not None:
-                path_dbg |= 0x00000002
-                pass_on_message = result.value
-            else:
-                path_dbg |= 0x00000004
-                try:
-                    pass_on_message = decoder.decode(
-                        str(message.topic), message.payload
-                    )
-                except Exception as e:
-                    path_dbg |= 0x00000008
-                    pass_on_error_event = e
-        else:
-            path_dbg |= 0x00000010
-            pass_on_error_event = result.value
-        if pass_on_message is not None:
-            path_dbg |= 0x00000020
-            queue.put_nowait(pass_on_message)
-        else:
-            path_dbg |= 0x00000040
+        try:
+            queue.put_nowait(decoder.decode(str(message.topic), message.payload))
+        except Exception as e:
             queue.put_nowait(
                 GWDEvent(
                     event=MQTTParseException(
                         Src=str(message.topic),
                         ProblemType=Problems.warning,
-                        Summary=f"ERROR parsing on topic {message.topic}: [{pass_on_error_event}]",
-                        Details=f"message:\n{message_str}",
+                        Summary=f"ERROR parsing on topic {message.topic}: [{e}]",
+                        Details=f"message:\n{message.payload}",
                         topic=str(message.topic),
                     )
                 )
@@ -162,4 +138,3 @@ def handle_message(
     except Exception as e:
         logger.exception(e)
         raise e
-    logger.debug(f"--mqtt message: 0x{path_dbg:08X}")
